@@ -341,9 +341,9 @@ def Fishconsole_Update():
                 if Forcedupdate:
                     if isConnected:
 
-                        import imp
-                        imp.reload(pkg_resources)
-                        imp.reload(fcv)
+                        import importlib
+                        importlib.reload(pkg_resources)
+                        importlib.reload(fcv)
 
 
                         系统日志(f"检测到网络连接成功", "强制更新系统", UPI)
